@@ -308,8 +308,9 @@ class Object2Vec(AmazonAlgorithmEstimatorBase):
         self.enc1_freeze_pretrained_embedding = enc1_freeze_pretrained_embedding
 
     def create_model(self, vpc_config_override=VPC_CONFIG_DEFAULT, **kwargs):
-        """Return a :class:`~sagemaker.amazon.Object2VecModel` referencing the
-        latest s3 model data produced by this Estimator.
+        """Return a :class:`~sagemaker.amazon.Object2VecModel`.
+
+        It references the latest s3 model data produced by this Estimator.
 
         Args:
             vpc_config_override (dict[str, list[str]]): Optional override for VpcConfig set on
@@ -327,12 +328,7 @@ class Object2Vec(AmazonAlgorithmEstimatorBase):
         )
 
     def _prepare_for_training(self, records, mini_batch_size=None, job_name=None):
-        """
-        Args:
-            records:
-            mini_batch_size:
-            job_name:
-        """
+        """Placeholder docstring"""
         if mini_batch_size is None:
             mini_batch_size = self.MINI_BATCH_SIZE
 
@@ -342,13 +338,16 @@ class Object2Vec(AmazonAlgorithmEstimatorBase):
 
 
 class Object2VecModel(Model):
-    """Reference Object2Vec s3 model data. Calling
-    :meth:`~sagemaker.model.Model.deploy` creates an Endpoint and returns a
+    """Reference Object2Vec s3 model data.
+
+    Calling :meth:`~sagemaker.model.Model.deploy` creates an Endpoint and returns a
     Predictor that calculates anomaly scores for datapoints.
     """
 
     def __init__(self, model_data, role, sagemaker_session=None, **kwargs):
         """
+        Initialization for Object2VecModel class.
+
         Args:
             model_data (str): The S3 location of a SageMaker model data
                 ``.tar.gz`` file.
