@@ -10,7 +10,7 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
-"""Placeholder docstring."""
+"""Placeholder docstring"""
 from __future__ import print_function, absolute_import
 
 from abc import ABCMeta, abstractmethod
@@ -38,6 +38,7 @@ METRICS_PERIOD_DEFAULT = 60  # seconds
 
 class AnalyticsMetricsBase(with_metaclass(ABCMeta, object)):
     """Base class for tuning job or training job analytics classes.
+
     Understands common functionality like persistence and caching.
     """
 
@@ -54,8 +55,9 @@ class AnalyticsMetricsBase(with_metaclass(ABCMeta, object)):
 
     def dataframe(self, force_refresh=False):
         """A pandas dataframe with lots of interesting results about this object.
-        Created by calling SageMaker List and Describe APIs and
-        converting them into a convenient tabular summary.
+
+        Created by calling SageMaker List and Describe APIs and converting them into a
+        convenient tabular summary.
 
         Args:
             force_refresh (bool): Set to True to fetch the latest data from
@@ -73,8 +75,8 @@ class AnalyticsMetricsBase(with_metaclass(ABCMeta, object)):
 
     def clear_cache(self):
         """Clear the object of all local caches of API methods.
-        So that the next time any properties are accessed they will be refreshed from the
-        service.
+
+        So that the next time any properties are accessed they will be refreshed from the service.
         """
         self._dataframe = None
 
@@ -103,7 +105,7 @@ class HyperparameterTuningJobAnalytics(AnalyticsMetricsBase):
 
     @property
     def name(self):
-        """Name of the HyperparameterTuningJob being analyzed."""
+        """Name of the HyperparameterTuningJob being analyzed"""
         return self._tuning_job_name
 
     def __repr__(self):
@@ -156,6 +158,7 @@ class HyperparameterTuningJobAnalytics(AnalyticsMetricsBase):
     @property
     def tuning_ranges(self):
         """A dictionary describing the ranges of all tuned hyperparameters.
+
         The keys are the names of the hyperparameter, and the values are the ranges.
 
         The output can take one of two forms:
@@ -207,7 +210,7 @@ class HyperparameterTuningJobAnalytics(AnalyticsMetricsBase):
         }
 
     def _prepare_parameter_ranges(self, parameter_ranges):
-        """Convert parameter ranges a dictionary using the parameter range names as the keys."""
+        """Convert parameter ranges a dictionary using the parameter range names as the keys"""
         out = {}
         for _, ranges in parameter_ranges.items():
             for param in ranges:
@@ -313,7 +316,7 @@ class TrainingJobAnalytics(AnalyticsMetricsBase):
 
     @property
     def name(self):
-        """Name of the TrainingJob being analyzed."""
+        """Name of the TrainingJob being analyzed"""
         return self._training_job_name
 
     def __repr__(self):
@@ -360,7 +363,7 @@ class TrainingJobAnalytics(AnalyticsMetricsBase):
         return pd.DataFrame(self._data)
 
     def _fetch_metric(self, metric_name):
-        """Fetch all the values of a named metric, and add them to _data.
+        """Fetch all the values of a named metric, and add them to _data
 
         Args:
             metric_name: The metric name to fetch.
@@ -564,6 +567,7 @@ class ExperimentAnalytics(AnalyticsMetricsBase):
 
     def _reshape_parameters(self, parameters):
         """Reshape trial component parameters to a pandas column.
+
         Args:
             parameters: trial component parameters
         Returns:
@@ -578,6 +582,7 @@ class ExperimentAnalytics(AnalyticsMetricsBase):
 
     def _reshape_metrics(self, metrics):
         """Reshape trial component metrics to a pandas column.
+
         Args:
             metrics: trial component metrics
         Returns:
@@ -598,6 +603,7 @@ class ExperimentAnalytics(AnalyticsMetricsBase):
 
     def _reshape_artifacts(self, artifacts, _artifact_names):
         """Reshape trial component input/output artifacts to a pandas column.
+
         Args:
             artifacts: trial component input/output artifacts
         Returns:
@@ -631,6 +637,7 @@ class ExperimentAnalytics(AnalyticsMetricsBase):
 
     def _reshape(self, trial_component):
         """Reshape trial component data to pandas columns.
+
         Args:
             trial_component: dict representing a trial component
         Returns:
@@ -660,9 +667,8 @@ class ExperimentAnalytics(AnalyticsMetricsBase):
         return out
 
     def _fetch_dataframe(self):
-        """Return a pandas dataframe with all the trial_components,
-        along with their parameters and metrics.
-        """
+        """Return a pandas dataframe includes all the trial_components."""
+
         df = pd.DataFrame([self._reshape(component) for component in self._get_trial_components()])
         return df
 
