@@ -181,8 +181,10 @@ class IngestionManagerPandas:
         logger.info("Started ingesting index %d to %d", start_index, end_index)
         for row in data_frame[start_index:end_index].itertuples(index=False):
             record = [
-                FeatureValue(feature_name=name, value_as_string=str(value))
-                for name, value in row._asdict().items()
+                FeatureValue(
+                    feature_name=data_frame.columns[index], value_as_string=str(row[index])
+                )
+                for index in range(len(row))
             ]
             sagemaker_session.put_record(
                 feature_group_name=feature_group_name, record=[value.to_dict() for value in record]
@@ -466,8 +468,7 @@ class FeatureGroup:
         raise RuntimeError("No metastore is configured with this feature group.")
 
     def as_hive_ddl(self, database: str = "sagemaker_featurestore", table_name: str = None) -> str:
-        """Generate Hive DDL commands that can be used to define or change structure of tables or
-        databases in Hive.
+        """Generate Hive DDL commands to define or change structure of tables or databases in Hive.
 
         Schema of the table is generated based on the feature definitions. Columns are named
         after feature name and data-type are inferred based on feature type. Integral feature
