@@ -10,9 +10,10 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
-"""This module contains code related to the ``Processor`` class, which is used
-for Amazon SageMaker Processing Jobs. These jobs let users perform data pre-processing,
-post-processing, feature engineering, data validation, and model evaluation,
+"""This module contains code related to the ``Processor`` class.
+
+which is used for Amazon SageMaker Processing Jobs. These jobs let users perform
+data pre-processing, post-processing, feature engineering, data validation, and model evaluation,
 and interpretation on Amazon SageMaker.
 """
 from __future__ import print_function, absolute_import
@@ -25,10 +26,13 @@ from six.moves.urllib.request import url2pathname
 
 from sagemaker import s3
 from sagemaker.job import _Job
+from sagemaker.local import LocalSession
 from sagemaker.utils import base_name_from_image, name_from_base
 from sagemaker.session import Session
 from sagemaker.network import NetworkConfig  # noqa: F401 # pylint: disable=unused-import
 from sagemaker.workflow.properties import Properties
+from sagemaker.dataset_definition.inputs import S3Input, DatasetDefinition
+from sagemaker.apiutils._base_types import ApiObject
 
 
 class Processor(object):
@@ -51,8 +55,9 @@ class Processor(object):
         tags=None,
         network_config=None,
     ):
-        """Initializes a ``Processor`` instance. The ``Processor`` handles Amazon
-        SageMaker Processing tasks.
+        """Initializes a ``Processor`` instance.
+
+        The ``Processor`` handles Amazon SageMaker Processing tasks.
 
         Args:
             role (str): An AWS IAM role name or ARN. Amazon SageMaker Processing
@@ -102,7 +107,6 @@ class Processor(object):
         self.output_kms_key = output_kms_key
         self.max_runtime_in_seconds = max_runtime_in_seconds
         self.base_job_name = base_job_name
-        self.sagemaker_session = sagemaker_session or Session()
         self.env = env
         self.tags = tags
         self.network_config = network_config
@@ -112,6 +116,12 @@ class Processor(object):
         self._current_job_name = None
         self.arguments = None
 
+        if self.instance_type in ("local", "local_gpu"):
+            if not isinstance(sagemaker_session, LocalSession):
+                sagemaker_session = LocalSession()
+
+        self.sagemaker_session = sagemaker_session or Session()
+
     def run(
         self,
         inputs=None,
@@ -277,13 +287,13 @@ class Processor(object):
                 if file_input.input_name is None:
                     file_input.input_name = "input-{}".format(count)
 
-                if isinstance(file_input.source, Properties):
+                if isinstance(file_input.source, Properties) or file_input.dataset_definition:
                     normalized_inputs.append(file_input)
                     continue
 
                 # If the source is a local path, upload it to S3
                 # and save the S3 uri in the ProcessingInput source.
-                parse_result = urlparse(file_input.source)
+                parse_result = urlparse(file_input.s3_input.s3_uri)
                 if parse_result.scheme != "s3":
                     desired_s3_uri = s3.s3_path_join(
                         "s3://",
@@ -293,18 +303,17 @@ class Processor(object):
                         file_input.input_name,
                     )
                     s3_uri = s3.S3Uploader.upload(
-                        local_path=file_input.source,
+                        local_path=file_input.s3_input.s3_uri,
                         desired_s3_uri=desired_s3_uri,
                         sagemaker_session=self.sagemaker_session,
                         kms_key=kms_key,
                     )
-                    file_input.source = s3_uri
+                    file_input.s3_input.s3_uri = s3_uri
                 normalized_inputs.append(file_input)
         return normalized_inputs
 
     def _normalize_outputs(self, outputs=None):
-        """Ensures that all the outputs are ``ProcessingOutput`` objects with
-        names and S3 URIs.
+        """Ensures that all the outputs are ``ProcessingOutput`` objects with names and S3 URIs.
 
         Args:
             outputs (list[sagemaker.processing.ProcessingOutput]): A list
@@ -364,9 +373,11 @@ class ScriptProcessor(Processor):
         tags=None,
         network_config=None,
     ):
-        """Initializes a ``ScriptProcessor`` instance. The ``ScriptProcessor``
-        handles Amazon SageMaker Processing tasks for jobs using a machine learning framework,
-        which allows for providing a script to be run as part of the Processing Job.
+        """Initializes a ``ScriptProcessor`` instance.
+
+        The ``ScriptProcessor`` handles Amazon SageMaker Processing tasks for jobs
+        using a machine learning framework, which allows for providing a script to be
+        run as part of the Processing Job.
 
         Args:
             role (str): An AWS IAM role name or ARN. Amazon SageMaker Processing
@@ -505,7 +516,6 @@ class ScriptProcessor(Processor):
         inputs_with_code = self._convert_code_and_add_to_inputs(inputs, user_code_s3_uri)
 
         self._set_entrypoint(self.command, user_script_name)
-
         return inputs_with_code
 
     def _get_user_code_name(self, code):
@@ -567,8 +577,7 @@ class ScriptProcessor(Processor):
         return user_code_s3_uri
 
     def _upload_code(self, code):
-        """Uploads a code file or directory specified as a string
-        and returns the S3 URI.
+        """Uploads a code file or directory specified as a string and returns the S3 URI.
 
         Args:
             code (str): A file or directory to be uploaded to S3.
@@ -601,6 +610,7 @@ class ScriptProcessor(Processor):
                 with the ``ProcessingInput`` object created from ``s3_uri`` appended to the list.
 
         """
+
         code_file_input = ProcessingInput(
             source=s3_uri,
             destination=str(
@@ -780,15 +790,12 @@ class ProcessingJob(_Job):
         if job_desc.get("ProcessingInputs"):
             inputs = [
                 ProcessingInput(
-                    source=processing_input["S3Input"]["S3Uri"],
-                    destination=processing_input["S3Input"]["LocalPath"],
                     input_name=processing_input["InputName"],
-                    s3_data_type=processing_input["S3Input"].get("S3DataType"),
-                    s3_input_mode=processing_input["S3Input"].get("S3InputMode"),
-                    s3_data_distribution_type=processing_input["S3Input"].get(
-                        "S3DataDistributionType"
+                    s3_input=S3Input.from_boto(processing_input.get("S3Input")),
+                    dataset_definition=DatasetDefinition.from_boto(
+                        processing_input.get("DatasetDefinition")
                     ),
-                    s3_compression_type=processing_input["S3Input"].get("S3CompressionType"),
+                    app_managed=processing_input.get("AppManaged", False),
                 )
                 for processing_input in job_desc["ProcessingInputs"]
             ]
@@ -797,15 +804,21 @@ class ProcessingJob(_Job):
         if job_desc.get("ProcessingOutputConfig") and job_desc["ProcessingOutputConfig"].get(
             "Outputs"
         ):
-            outputs = [
-                ProcessingOutput(
-                    source=processing_output["S3Output"]["LocalPath"],
-                    destination=processing_output["S3Output"]["S3Uri"],
-                    output_name=processing_output["OutputName"],
+            outputs = []
+            for processing_output_dict in job_desc["ProcessingOutputConfig"]["Outputs"]:
+                processing_output = ProcessingOutput(
+                    output_name=processing_output_dict["OutputName"],
+                    app_managed=processing_output_dict.get("AppManaged", False),
+                    feature_store_output=FeatureStoreOutput.from_boto(
+                        processing_output_dict.get("FeatureStoreOutput")
+                    ),
                 )
-                for processing_output in job_desc["ProcessingOutputConfig"]["Outputs"]
-            ]
 
+                if "S3Output" in processing_output_dict:
+                    processing_output.source = processing_output_dict["S3Output"]["LocalPath"]
+                    processing_output.destination = processing_output_dict["S3Output"]["S3Uri"]
+
+                outputs.append(processing_output)
         output_kms_key = None
         if job_desc.get("ProcessingOutputConfig"):
             output_kms_key = job_desc["ProcessingOutputConfig"].get("KmsKeyId")
@@ -967,17 +980,21 @@ class ProcessingInput(object):
 
     def __init__(
         self,
-        source,
-        destination,
+        source=None,
+        destination=None,
         input_name=None,
         s3_data_type="S3Prefix",
         s3_input_mode="File",
         s3_data_distribution_type="FullyReplicated",
         s3_compression_type="None",
+        s3_input=None,
+        dataset_definition=None,
+        app_managed=False,
     ):
-        """Initializes a ``ProcessingInput`` instance. ``ProcessingInput`` accepts parameters
-        that specify an Amazon S3 input for a processing job and provides a method
-        to turn those parameters into a dictionary.
+        """Initializes a ``ProcessingInput`` instance.
+
+        ``ProcessingInput`` accepts parameters that specify an Amazon S3 input
+        for a processing job and provides a method to turn those parameters into a dictionary.
 
         Args:
             source (str): The source for the input. If a local path is provided, it will
@@ -991,6 +1008,11 @@ class ProcessingInput(object):
             s3_data_distribution_type (str): Valid options are "FullyReplicated"
                 or "ShardedByS3Key".
             s3_compression_type (str): Valid options are "None" or "Gzip".
+            s3_input (:class:`~sagemaker.dataset_definition.S3Input`)
+                Metadata of data objects stored in S3
+            dataset_definition (:class:`~sagemaker.dataset_definition.DatasetDefinition`)
+                DatasetDefinition input
+            app_managed (bool): Whether the input are managed by SageMaker or application
         """
         self.source = source
         self.destination = destination
@@ -999,30 +1021,60 @@ class ProcessingInput(object):
         self.s3_input_mode = s3_input_mode
         self.s3_data_distribution_type = s3_data_distribution_type
         self.s3_compression_type = s3_compression_type
+        self.s3_input = s3_input
+        self.dataset_definition = dataset_definition
+        self.app_managed = app_managed
+        self._create_s3_input()
 
     def _to_request_dict(self):
         """Generates a request dictionary using the parameters provided to the class."""
-        # Create the request dictionary.
-        s3_input_request = {
-            "InputName": self.input_name,
-            "S3Input": {
-                "S3Uri": self.source,
-                "LocalPath": self.destination,
-                "S3DataType": self.s3_data_type,
-                "S3InputMode": self.s3_input_mode,
-                "S3DataDistributionType": self.s3_data_distribution_type,
-            },
-        }
 
-        # Check the compression type, then add it to the dictionary.
-        if self.s3_compression_type == "Gzip" and self.s3_input_mode != "Pipe":
-            raise ValueError("Data can only be gzipped when the input mode is Pipe.")
-        if self.s3_compression_type is not None:
-            s3_input_request["S3Input"]["S3CompressionType"] = self.s3_compression_type
+        # Create the request dictionary.
+        s3_input_request = {"InputName": self.input_name, "AppManaged": self.app_managed}
+
+        if self.s3_input:
+            # Check the compression type, then add it to the dictionary.
+            if (
+                self.s3_input.s3_compression_type == "Gzip"
+                and self.s3_input.s3_input_mode != "Pipe"
+            ):
+                raise ValueError("Data can only be gzipped when the input mode is Pipe.")
+
+            s3_input_request["S3Input"] = S3Input.to_boto(self.s3_input)
+
+        if self.dataset_definition is not None:
+            s3_input_request["DatasetDefinition"] = DatasetDefinition.to_boto(
+                self.dataset_definition
+            )
 
         # Return the request dictionary.
         return s3_input_request
 
+    def _create_s3_input(self):
+        """Create and initialize S3Input.
+
+        When client provides S3Input, backfill other class memebers because they are used
+        in other places. When client provides other S3Input class memebers, create and
+        init S3Input.
+        """
+
+        if self.s3_input is not None:
+            # backfill other class members
+            self.source = self.s3_input.s3_uri
+            self.destination = self.s3_input.local_path
+            self.s3_data_type = self.s3_input.s3_data_type
+            self.s3_input_mode = self.s3_input.s3_input_mode
+            self.s3_data_distribution_type = self.s3_input.s3_data_distribution_type
+        elif self.source and self.destination:
+            self.s3_input = S3Input(
+                s3_uri=self.source,
+                local_path=self.destination,
+                s3_data_type=self.s3_data_type,
+                s3_input_mode=self.s3_input_mode,
+                s3_data_distribution_type=self.s3_data_distribution_type,
+                s3_compression_type=self.s3_compression_type,
+            )
+
 
 class ProcessingOutput(object):
     """Accepts parameters that specify an Amazon S3 output for a processing job.
@@ -1030,10 +1082,19 @@ class ProcessingOutput(object):
     It also provides a method to turn those parameters into a dictionary.
     """
 
-    def __init__(self, source, destination=None, output_name=None, s3_upload_mode="EndOfJob"):
-        """Initializes a ``ProcessingOutput`` instance. ``ProcessingOutput`` accepts parameters that
-        specify an Amazon S3 output for a processing job and provides a method to turn
-        those parameters into a dictionary.
+    def __init__(
+        self,
+        source=None,
+        destination=None,
+        output_name=None,
+        s3_upload_mode="EndOfJob",
+        app_managed=False,
+        feature_store_output=None,
+    ):
+        """Initializes a ``ProcessingOutput`` instance.
+
+        ``ProcessingOutput`` accepts parameters that specify an Amazon S3 output for a
+        processing job and provides a method to turn those parameters into a dictionary.
 
         Args:
             source (str): The source for the output.
@@ -1043,23 +1104,42 @@ class ProcessingOutput(object):
             output_name (str): The name of the output. If a name
                 is not provided, one will be generated (eg. "output-1").
             s3_upload_mode (str): Valid options are "EndOfJob" or "Continuous".
+            app_managed (bool): Whether the input are managed by SageMaker or application
+            feature_store_output (:class:`~sagemaker.processing.FeatureStoreOutput`)
+                Configuration for processing job outputs of FeatureStore.
         """
         self.source = source
         self.destination = destination
         self.output_name = output_name
         self.s3_upload_mode = s3_upload_mode
+        self.app_managed = app_managed
+        self.feature_store_output = feature_store_output
 
     def _to_request_dict(self):
         """Generates a request dictionary using the parameters provided to the class."""
         # Create the request dictionary.
         s3_output_request = {
             "OutputName": self.output_name,
-            "S3Output": {
+            "AppManaged": self.app_managed,
+        }
+
+        if self.source is not None:
+            s3_output_request["S3Output"] = {
                 "S3Uri": self.destination,
                 "LocalPath": self.source,
                 "S3UploadMode": self.s3_upload_mode,
-            },
-        }
+            }
+
+        if self.feature_store_output is not None:
+            s3_output_request["FeatureStoreOutput"] = FeatureStoreOutput.to_boto(
+                self.feature_store_output
+            )
 
         # Return the request dictionary.
         return s3_output_request
+
+
+class FeatureStoreOutput(ApiObject):
+    """Configuration for processing job outputs in Amazon SageMaker Feature Store."""
+
+    feature_group_name = None
