@@ -39,7 +39,13 @@ class PyTorchPredictor(Predictor):
     multidimensional tensors for PyTorch inference.
     """
 
-    def __init__(self, endpoint_name, sagemaker_session=None):
+    def __init__(
+        self,
+        endpoint_name,
+        sagemaker_session=None,
+        serializer=NumpySerializer(),
+        deserializer=NumpyDeserializer(),
+    ):
         """Initialize an ``PyTorchPredictor``.
 
         Args:
@@ -49,16 +55,22 @@ class PyTorchPredictor(Predictor):
                 manages interactions with Amazon SageMaker APIs and any other
                 AWS services needed. If not specified, the estimator creates one
                 using the default AWS configuration chain.
+            serializer (sagemaker.serializers.BaseSerializer): Optional. Default
+                serializes input data to .npy format. Handles lists and numpy
+                arrays.
+            deserializer (sagemaker.deserializers.BaseDeserializer): Optional.
+                Default parses the response from .npy format to numpy array.
         """
         super(PyTorchPredictor, self).__init__(
-            endpoint_name, sagemaker_session, NumpySerializer(), NumpyDeserializer()
+            endpoint_name,
+            sagemaker_session,
+            serializer=serializer,
+            deserializer=deserializer,
         )
 
 
 class PyTorchModel(FrameworkModel):
-    """An PyTorch SageMaker ``Model`` that can be deployed to a SageMaker
-    ``Endpoint``.
-    """
+    """An PyTorch SageMaker ``Model`` that can be deployed to a SageMaker ``Endpoint``."""
 
     _framework_name = "pytorch"
     _LOWEST_MMS_VERSION = "1.2"
@@ -198,8 +210,7 @@ class PyTorchModel(FrameworkModel):
         )
 
     def prepare_container_def(self, instance_type=None, accelerator_type=None):
-        """Return a container definition with framework configuration set in
-        model environment variables.
+        """A container definition with framework configuration set in model environment variables.
 
         Args:
             instance_type (str): The EC2 instance type to deploy this Model to.
@@ -261,7 +272,10 @@ class PyTorchModel(FrameworkModel):
         )
 
     def _is_mms_version(self):
-        """Whether the framework version corresponds to an inference image using
+        """
+        Determines if the framework corresponds to an and using MMS.
+
+        Whether the framework version corresponds to an inference image using
         the Multi-Model Server (https://github.com/awslabs/multi-model-server).
 
         Returns:
