@@ -31,10 +31,17 @@ class SparkMLPredictor(Predictor):
     list.
     """
 
-    def __init__(self, endpoint_name, sagemaker_session=None, **kwargs):
-        """Initializes a SparkMLPredictor which should be used with SparkMLModel
-        to perform predictions against SparkML models serialized via MLeap. The
-        response is returned in text/csv format which is the default response
+    def __init__(
+        self,
+        endpoint_name,
+        sagemaker_session=None,
+        serializer=CSVSerializer(),
+        **kwargs,
+    ):
+        """Initializes a SparkMLPredictor which should be used with SparkMLModel.
+
+        It is used to perform predictions against SparkML models serialized via MLeap.
+        The response is returned in text/csv format which is the default response
         format for SparkML Serving container.
 
         Args:
@@ -43,18 +50,21 @@ class SparkMLPredictor(Predictor):
                 manages interactions with Amazon SageMaker APIs and any other
                 AWS services needed. If not specified, the estimator creates one
                 using the default AWS configuration chain.
+            serializer (sagemaker.serializers.BaseSerializer): Optional. Default
+                serializes input data to text/csv.
         """
         sagemaker_session = sagemaker_session or Session()
         super(SparkMLPredictor, self).__init__(
             endpoint_name=endpoint_name,
             sagemaker_session=sagemaker_session,
-            serializer=CSVSerializer(),
+            serializer=serializer,
             **kwargs,
         )
 
 
 class SparkMLModel(Model):
     """Model data and S3 location holder for MLeap serialized SparkML model.
+
     Calling :meth:`~sagemaker.model.Model.deploy` creates an Endpoint and return
     a Predictor to performs predictions against an MLeap serialized SparkML
     model .
